%% PD Control Design for Servo Position
% 1) Enter model parameters found experimentally
% 2) Run script to generate PD gains
% 3) Test on QUBE-Servo 2 using Simulink/QUARC model
% 
%% First-Order Model Parameters
K = 11; % steady-state gain
T = 0.25; % time constant
% 
%% Time-domain specifications
% Peak time (s)
tp = 0.1;
% Percent overshoot (%)
PO = 5;
% 
%% PD Design
% Damping ratio from overshoot specification.
zeta = -log(PO/100) * sqrt( 1 / ( ( log(PO/100) )^2 + pi^2 ) );
% Natural frequency from specifications (rad/s)
wn = pi / ( tp * sqrt(1-zeta^2) );
% Proportional gain (V/rad)
kp = wn^2/K*T;
% Derivative gain (V-s/rad)
kd = (-1+2*zeta*wn*T)/K;
% Display
disp(['kp = ', num2str(kp)]);
disp(['kd = ', num2str(kd)]);
